@@ -8,7 +8,7 @@ Sys.setenv(R_CHECK_SYSTEM_CLOCK = FALSE) ## Sys.getenv("R_CHECK_SYSTEM_CLOCK", u
 
 #' A virtual function to use as a contains argument when writing APT samplers
 #'
-#' Modified from nimble's samplers_BASE to include a setTemp method
+#' Modified from NIMBLE's samplers_BASE to include a setTemp method
 #'
 #' Set up functions for this class should include the following arguments
 #'
@@ -75,7 +75,7 @@ sampler_APT <- nimbleFunctionVirtual(
 
 
 ######################################################################################
-## buildAPT was adapted from nimble's buildMCMC to provide adaptive parallel tempering
+## buildAPT was adapted from NIMBLE's buildMCMC to provide adaptive parallel tempering
 ######################################################################################
 
 ##' Create an APT function, from an MCMCconf object
@@ -100,6 +100,13 @@ sampler_APT <- nimbleFunctionVirtual(
 ##' already existing sample chains. Generally, \code{reset=FALSE} should only
 ##' be used when the MCMC has already been run (default = TRUE).
 ##'
+##' \code{resetMV}: Boolean specifying whether to begin recording posterior sample chains anew. This
+##' argument is only considered when using \code{reset = FALSE}.  Specifying \code{reset = FALSE,
+##' resetMV = TRUE} allows the MCMC algorithm to continue running from where it left off, but
+##' without appending the new posterior samples to the already existing samples, i.e. all previously
+##' obtained samples will be erased. This option can help reduce memory usage during burn-in
+##' (default = FALSE).
+##'
 ##' \code{resetTempering} Boolean specifying whether to reset the
 ##' flexibility of the temperature ladder's adaptation process.
 ##'
@@ -186,7 +193,7 @@ sampler_APT <- nimbleFunctionVirtual(
 ##' @author David Pleydell, Daniel Turek
 ##'
 ##' @return
-##' Calling \code{buildAPT} returns an uncompiled APT function object. This is very similar to how NIMBLE's \code{buildMCMC} function returns an uncompiled MCMC function object. See \code{?buildMCMC}. Users shold be familiar with the chapter 'MCMC' of the NIMBLE manual.
+##' Calling \code{buildAPT} returns an uncompiled APT function object. This is very similar to how NIMBLE's \code{buildMCMC} function returns an uncompiled MCMC function object. See \code{?buildMCMC}. Users should be familiar with the chapter 'MCMC' of the NIMBLE manual.
 ##'
 ##' @name buildAPT
 ##'
@@ -323,6 +330,7 @@ buildAPT <- nimbleFunction(
     #################################################
     run = function(niter          = integer(),
                    reset          = logical(default=TRUE),
+                   resetMV        = logical(default = FALSE), ## Allows resetting mvSamples when reset==FALSE
                    resetTempering = logical(default=FALSE),
                    simulateAll    = logical(default=FALSE),
                    time           = logical(default=FALSE),
@@ -362,26 +370,22 @@ buildAPT <- nimbleFunction(
             }
             mvSamples_offset  <- 0
             mvSamples2_offset <- 0
-            setSize(tempTraj,  niter/thinToUseVec[1], nTemps)
-            resize(mvSamples,  niter/thinToUseVec[1])
-            resize(mvSamples2, niter/thinToUseVec[2])
-            if (monitorTmax==TRUE) {
-                resize(mvSamplesTmax,  niter/thinToUseVec[1])
-                resize(mvSamples2Tmax, niter/thinToUseVec[2])
-            }
-            logProbs <<- resizeVector(logProbs, niter/thinToUseVec[1])
         } else {
             mvSamples_offset  <- getsize(mvSamples)
             mvSamples2_offset <- getsize(mvSamples2)
-            setSize(tempTraj,  niter/thinToUseVec[1], nTemps)
-            resize(mvSamples,  mvSamples_offset  + niter/thinToUseVec[1])
-            resize(mvSamples2, mvSamples2_offset + niter/thinToUseVec[2])
-            if (monitorTmax==TRUE) {
-                resize(mvSamplesTmax,  mvSamples_offset  + niter/thinToUseVec[1])
-                resize(mvSamples2Tmax, mvSamples2_offset + niter/thinToUseVec[2])
+            if (resetMV) {
+                mvSamples_offset  <- 0
+                mvSamples2_offset <- 0
             }
-            logProbs <<- resizeVector(logProbs, mvSamples_offset + niter/thinToUseVec[1])
         }
+        setSize(tempTraj,  niter/thinToUseVec[1], nTemps)
+        resize(mvSamples,  mvSamples_offset  + niter/thinToUseVec[1])
+        resize(mvSamples2, mvSamples2_offset + niter/thinToUseVec[2])
+        if (monitorTmax==TRUE) {
+            resize(mvSamplesTmax,  mvSamples_offset  + niter/thinToUseVec[1])
+            resize(mvSamples2Tmax, mvSamples2_offset + niter/thinToUseVec[2])
+        }
+        logProbs <<- resizeVector(logProbs, mvSamples_offset + niter/thinToUseVec[1])
         ##### Monitors & Progress Bar #####
         if(dim(samplerTimes)[1] != length(samplerFunctions))
             setSize(samplerTimes, length(samplerFunctions))
@@ -795,10 +799,10 @@ sampler_RW_block_tempered <- nimbleFunction(
         my_calcAdaptationFactor <- calcAdaptationFactor(d, adaptFactorExponent)
         ## checks
         ## browser()
-        if(class(propCov)[1]   != 'matrix')  stop('propCov must be a matrix\n')
-        if(class(propCov[1,1]) != 'numeric') stop('propCov matrix must be numeric\n')
-        if(!all(dim(propCov)   == d))        stop('propCov matrix must have dimension ', d, 'x', d, '\n')
-        if(!isSymmetric(propCov))            stop('propCov matrix must be symmetric')
+        if(!inherits(propCov, 'matrix')) stop('propCov must be a matrix\n')
+        if(!inherits(propCov[1,1], 'numeric')) stop('propCov matrix must be numeric\n')
+        if(!all(dim(propCov)   == d)) stop('propCov matrix must have dimension ', d, 'x', d, '\n')
+        if(!isSymmetric(propCov)) stop('propCov matrix must be symmetric')
         ## Initialise temperature
         temperature <- nimNumeric(length=2, value=1) ## Length 2 is a hack. Only temperature[1] is used.
     },
@@ -1192,7 +1196,7 @@ sampler_RW_multinomial_tempered <- nimbleFunction(
 #' \itemize{
 #' \item adaptive.  A logical argument, specifying whether the sampler should adapt the binomial proposal probabilities throughout the course of MCMC execution. (default = TRUE)
 #' \item adaptInterval.  The interval on which to perform adaptation.  A minimum value of 100 is required. (default = 200)
-#' \item useTempering. A logical argument to optionally turn temporing off (i.e. assume all temperatures are 1) for this sampler.
+#' \item useTempering. A logical argument to optionally turn tempering off (i.e. assume all temperatures are 1) for this sampler.
 #' }
 #'
 #' @name samplers
@@ -1293,7 +1297,7 @@ plotTempTraj <- function(cAPT) {
 
 
 
-## Copied from nimble since they do not export this function
+## Copied from NIMBLE since they do not export this function
 mcmc_checkWAICmonitors <- function(model, monitors, dataNodes) {
     monitoredDetermNodes <- model$expandNodeNames(monitors)[model$isDeterm(model$expandNodeNames(monitors))]
     if(length(monitoredDetermNodes) > 0) {
